_SUPPORTED_CURRENCIES = {
   "Albanian lek": "ALL",
   "Danish krone": "DKK",
   "Lesotho loti": "LSL",
   "Samoan tālā": "WST",
   "Algerian dinar": "DZD",
   "Djiboutian franc": "DJF",
   "Malagasy ariary": "MGA",
   "Serbian dinar": "RSD",
   "Argentine peso": "ARS",
   "Dominican peso": "DOP",
   "Malawian kwacha": "MWK",
   "Singapore dollar": "SGD",
   "Armenian dram": "AMD",
   "Eastern Caribbean dollar": "XCD",
   "Malaysian ringgit": "MYR",
   "Solomon Islands dollar": "SBD",
   "Australian dollar": "AUD",
   "Euro": "EUR",
   "Mauritian rupee": "MUR",
   "South African rand": "ZAR",
   "Azerbaijani manat": "AZN",
   "Fijan dollar": "FJD",
   "Mexican peso": "MXN",
   "Sri Lankan rupee": "LKR",
   "Bahamian dollar": "BSD",
   "Gambian dalasi": "GMD",
   "Moroccan dirham": "MAD",
   "Surinamese dollar": "SRD",
   "Bahraini dinar": "BHD",
   "Georgian lari": "GEL",
   "Mozambican metical": "MZN",
   "Swedish krona": "SEK",
   "Bangladeshi taka": "BDT",
    #"Ghanaian cedi": 
   "GHS Namibian dollar": "NAD",
   "Swiss franc": "CHF",
   "Barbadian dollar": "BBD",
   "Guatemalan quetzal": "GTQ",
   "Nepalese rupee": "NPR",
   "New Taiwan dollar": "TWD",
   "Bhutanese ngultrum": "BTN",
   "Guinean franc": "GNF",
   "New Zealand dollar": "NZD",
   "Tajikistani somoni": "TJS",
   "Bolivian boliviano": "BOB",
   "Honduran lempira": "HNL",
   "Macedonian denar": "MKD",
   "Tanzanian shilling": "TZS",
   "Bosnia and Herzegovina convertible mark": "BAM",
   "Hong Kong dollar": "HKD",
   "Norwegian krone": "NOK",
   "Thai baht": "THB",
   "Botswana pula": "BWP",
   "Hungarian forint": "HUF",
   "Omani rial": "OMR",
   "Tongan paʻanga": "TOP",
   "Brunei dollar": "BND",
   "Indian rupee": "INR",
   "Pakistani rupee": "PKR",
   "Trinidad and Tobago dollar": "TTD",
   "Indonesian rupiah": "IDR",
   "Papua New Guinean kina": "PGK",
   "Tunisian dinar": "TND",
   "Israeli new shekel": "ILS",
   "Paraguayan guaraní": "PYG",
   "Turkish lira": "TRY",
   "Cape Verdean escudo": "CVE",
   "Jamaican dollar": "JMD",
   "Peruvian sol": "PEN",
   "Ugandan shilling": "UGX",
   "Japanese yen": "JPY",
   "Philippine peso": "PHP",
   "United Arab Emirates dirham": "AED",
   "Jordanian dollar": "JOD",
   "Polish złoty": "PLN",
   "British pound": "GBP",
   "Kazakhstani tenge": "KZT",
   "Qatari riyal": "QAR",
   "United States dollar": "USD",
   "Kenyan shilling": "KES",
   "Romanian leu": "RON",
   "Uruguayan peso": "UYU",
   "South Korean won": "KRW",
   "Russian ruble": "RUB",
   "Vanuatu vatu": "VUV",
   "Kuwaiti dinar": "KWD",
   "Rwandan franc": "RWF",
   "Vietnamese đồng": "VND",
}
